"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const koa_1 = __importDefault(require("koa"));
const koa_bodyparser_1 = __importDefault(require("koa-bodyparser"));
const koa_router_1 = __importDefault(require("koa-router"));
const supertest_1 = __importDefault(require("supertest"));
const index_1 = require("../index");
const ActionController_1 = require("./util/controllers/ActionController");
const ArgController_1 = require("./util/controllers/ArgController");
const ProtectedController_1 = require("./util/controllers/ProtectedController");
let app;
let router;
let nativeServer;
let testServer;
beforeAll(async () => {
    app = new koa_1.default();
    router = new koa_router_1.default();
    app.use(koa_bodyparser_1.default());
    app.use(router.routes());
    app.use(router.allowedMethods());
    await index_1.bootstrapControllers(app, {
        basePath: "/api",
        controllers: [ActionController_1.ActionController, ArgController_1.ArgController, ProtectedController_1.ProtectedController],
        versions: ["1", "2"],
        router
    });
    nativeServer = app.listen();
    testServer = supertest_1.default(nativeServer);
});
afterAll(done => {
    if (nativeServer.listening) {
        nativeServer.close(done);
    }
    else {
        done();
    }
});
describe("bootstrapping server", () => {
    it("should succeed ", async () => {
        const response = await testServer.get("/api/v2/action").expect(200);
        expect(response.text).toEqual("okay");
    });
    it("succeeds with multiple API Versions ", async () => {
        let response = await testServer.get("/api/v1/action").expect(200);
        expect(response.text).toEqual("okay");
        response = await testServer.get("/api/v2/action").expect(200);
        expect(response.text).toEqual("okay");
    });
    it("should fail when trying to access an undefined version", async () => {
        await testServer.get("/api/v3/action").expect(404);
    });
});
//# sourceMappingURL=bootstrap.test.js.map